/*!
 * Facebook Signin Control
 *
 * @since 1.0.0
 * @pacakge core
*/
var FacebookSignin = ControlSigninBase.extend({

	sdk: 'facebook',
	name: 'facebook',

	defaults: {},

	init: function() {

		this.permissions = this.rest_permissions = [ 'public_profile', 'email' ];
	},

	_render: function() {

		var self = this;

		// Check login status
		var loggedin = false;
		FB.getLoginStatus(function( response ) {
			self.check_permissions( response, function() {
				loggedin = true;
				self.remove_loading_state();
			});
		});

		setTimeout(function() {
			if ( ! loggedin ) {
				self.set_error( cl.__.notices.invlid_facebook_app_id );
				self.show_error();
			}
		}, 30000 );
	},

	connect: function( callback ) {

		var self = this;

		if ( 'connected' === self._status && ! self.rest_permissions.length ) {
			self._identify( function( data ) {
				callback( data, self._service_data );
			});
			return;
		}

		var result = false;
		self._track_window( 'facebook.com/dialog/oauth', function() {
			setTimeout(function() {

				if ( result ) {
					return;
				}

				self.locker.do_action( 'raw-social-app-declined' );
				self.show_notice( cl.__.errors.not_signed_in );

			}, 500 );
		});

		FB.login(function( response ) {

			result = true;
			self.check_permissions( response, function() {

				if ( 'connected' !== self._status ) {
					self.locker.do_action( 'raw-social-app-declined' );
					self.show_notice( cl.__.errors.not_signed_in );
				} else if ( self.rest_permissions.length ) {
					self.locker.do_action( 'raw-social-app-declined' );
					self.show_notice( cl.__.errors.not_granted.replace( '{permissions}', self.rest_permissions.join( ', ' ) ) );
				} else {
					self._identify( function( data ) {
						callback( data, self._service_data );
					});
				}
			});

		}, {
			scope: self.rest_permissions.join( ',' )
		});
	},

	check_permissions: function( response, callback ) {

		var self = this;

		self._status = response.status;
		self._service_data = response;

		// Check for permission if connected
		if ( response && 'connected' === self._status ) {

			FB.api( '/me/permissions', function( response ) {

				if ( response && response.data ) {
					var rest = [];
					$.each( response.data, function() {
						if ( 'granted' !== this.status ) {
							rest.push( this.permission );
						}
					});

					self.rest_permissions = rest;

					if ( callback ) {
						callback();
					}
				}
			});
		} else {
			if ( response && callback ) {
				callback();
			}
		}
	},

	_identify: function( callback ) {

		FB.api( '/me?fields=email,first_name,last_name,gender,link', function( response ) {

			var data = {};
			if ( response ) {
				data.source = 'facebook';
				data.social = true;
				data.email = response.email;
				data.display_name = response.first_name + ' ' + response.last_name;
				data.name = response.first_name;
				data.family = response.last_name;
				data.gender = response.gender;
				data.facebook_url = response.link;
				data.image = 'https://graph.facebook.com/' + response.id + '/picture?type=large';
			}

			callback( data );
		});
	}
});
cl.controls.facebook = FacebookSignin;
