/*!
 * Google Plus Control
 *
 * @since 1.0.0
 * @pacakge core
*/
var GooglePlus = ControlBase.extend({

	sdk: 'google',
	name: 'google-plus',

	defaults: {
		url: null,
		lang: 'en-US',
		size: 'medium',
		annotation: 'bubble',
		width: null,
		align: 'left',
		recommendations: true,
		clientId: null,
		calltoactionlabel: 'RECOMMEND',
		prefilltext: null
	},

	init: function() {

		if ( ! cl.settings.get( 'google' ).client_id ) {
			this.set_error( cl.__.notices.empty_google_clientid );
		}

		if ( this.has_error() ) {
			return this;
		}

		if ( this.locker.is_vertical() ) {
			this.options.size = 'tall';
		}

		if ( ! this.locker.has_counters() ) {
			this.options.annotation = 'none';
		}

		this.options.clientId = cl.settings.get( 'google' ).client_id;
	},

	create_events: function() {

		var self = this;
		$( document ).on( 'mts-cl-google-plus', function() {
			cl.active_locker.unlock( 'button', self.name, self );
		});
	},

	_render: function() {
		var self = this,
			hash = cl.helpers.hash( self.options.url ),
			callback = 'googleOnShareCallback_' + hash,
			attributes = {
				'class': 'g-plusone',
				'data-href': self.options.url,
				'data-size': self.options.size,
				'data-annotation': self.options.annotation,
				'data-align': self.options.align,
				'data-recommendations': self.options.recommendations,
				'data-callback': 'google_plusone_callback'
			},
			overlayAttributes = {
				'class': 'mts-cl-control-overlay g-interactivepost',
				'data-contenturl': self.options.url,
				'data-clientid': self.options.clientId,
				'data-cookiepolicy': 'none',
				'data-calltoactionurl': self.options.url,
				'data-onshare': callback
			};

		if ( self.options.width ) {
			attributes['data-width'] = self.options.width;
		}

		if ( self.options.calltoactionlabel ) {
			attributes['data-calltoactionlabel'] = self.options.calltoactionlabel;
		}

		if ( self.options.prefilltext ) {
			attributes['data-prefilltext'] = self.options.prefilltext;
		}

		if ( ! ( callback in window ) ) {
			window[ callback ] = function( obj ) {
				if ( obj && 'shared' === obj.action ) {
					$( document ).trigger( 'mts-cl-google-plus', [obj] );
				}
			};
		}

		var control = $( '<div></div>', attributes ),
			overlay = $( '<div></div>', overlayAttributes );

		self.container.find( '.mts-cl-social-control-wrapper' ).after( overlay );
		self.el.replaceWith( control );

		window.gapi.plusone.go( self.container[0] );
		window.gapi.interactivepost.go( self.container[0] );

		return this;
	}
});
cl.controls['google-plus'] = GooglePlus;
