/*!
 * Google Signin Control
 *
 * @since 1.0.0
 * @pacakge core
*/
var GoogleSignin = ControlSigninBase.extend({

	sdk: 'google',
	name: 'google',

	defaults: {},

	init: function() {

		if ( ! cl.settings.get( 'google' ).client_id ) {
			this.set_error( cl.__.notices.empty_google_clientid );
		}

		this.permissions = [ 'https://www.googleapis.com/auth/userinfo.profile', 'https://www.googleapis.com/auth/userinfo.email' ];

		if ( -1 !== $.inArray( 'youtube_subscribe', this.options.actions ) ) {
			this.permissions.push( 'https://www.googleapis.com/auth/youtube' );
		}

		if ( this.has_error() ) {
			return this;
		}

		this.rest_permissions = this.permissions;
	},

	_render: function() {
		this.remove_loading_state();
	},

	connect: function( callback ) {

		var self = this,
			result = false,
			options = {
				callback: function( response ) {

					if ( 'immediate_failed' !== response.error ) {
						result = true;

						if ( response && response.status.signed_in ) {
							self._identify( function( status, data ) {

								if ( 'error' === status ) {
									self.show_notice( cl.__.notices.unexpected_error.replace( '{0}', data ) );
									return;
								}

								callback( data, response );
							});
						} else {
							self.locker.do_action( 'raw-social-app-declined' );
							self.show_notice( cl.__.errors.not_signed_in );
						}
					}
				}
			};

		options.clientid = cl.settings.get( 'google' ).client_id;
		options.cookiepolicy = 'single_host_origin';
		options.scope = this.permissions.join( ' ' );

		self._track_window( 'google.com/o/oauth2', function() {
			setTimeout(function() {

				if ( result ) {
					return;
				}

				self.locker.do_action( 'raw-social-app-declined' );
				self.show_notice( cl.__.errors.not_signed_in );

			}, 500 );
		});

		gapi.auth.signIn( options );
	},

	_identify: function( callback ) {

		gapi.client.load( 'plus', 'v1' ).then(function() {

			gapi.client.plus.people.get({ userId: 'me' }).then(function( response ) {

				var data = {};
				if ( response && response.result ) {

					response = response.result;

					data.source = 'google';
					data.social = true;
					data.email = response.emails && response.emails[0] && response.emails[0].value;
					data.display_name = response.displayName;
					data.name = response.name && response.name.givenName;
					data.family = response.name && response.name.familyName;
					data.gender = response.gender;
					data.google_url = response.url;
					data.image = (function() {
						if ( response.image && response.image.url ) {
							return response.image.url.replace( /\?sz=\d+/gi, '' );
						}

						return '';
					})();
					callback( 'success', data );
				} else {
					callback( 'error', {} );
				}

			}, function( response ) {
				callback( 'error', response.result.error.message );
			});
		});
	},

	run_youtube_subscribe_action: function( lead, serviceData, action, loader, callback ) {

		var self = this;

		gapi.client.load( 'youtube', 'v3', function() {

			var request = gapi.client.youtube.subscriptions.insert({
				part: 'snippet',
				resource: {
					snippet: {
						resourceId: {
							kind: 'youtube#channel',
							channelId: self.options.youtube.channel_id
						}
					}
				}
			});

			request.execute(function( response ) {

				if ( response && response.error ) {

					if ( response.error.data && response.error.data[0] && 'subscriptionDuplicate' === response.error.data[0].reason ) {
						callback();
					} else {
						callback( 'error' );
						self.show_notice( response.error.message );
						console.log( response );
					}
				} else {
					self.locker.do_action( 'got-youtube-subscriber', [ response ] );
					callback();
				}
			});
		});
	}
});
cl.controls.google = GoogleSignin;
