/*!
 * Twitter Tweet Control
 *
 * @since 1.0.0
 * @pacakge core
*/
var TwitterTweet = ControlBase.extend({

	sdk: 'twitter',
	name: 'twitter-tweet',

	defaults: {
		url: null,
		text: null,
		via: null,
		button_title: null,
		size: 'medium',
		auth: false,
		lang: cl.settings.get( 'short_lang' )
	},

	verification: {
		timeout: 6e5
	},

	create_events: function() {

		var self = this;
		$( document ).on( 'mts-cl-twitter-tweet', function() {
			cl.active_locker.unlock( 'button', self.name, self );
		});
	},

	_render: function() {
		var self = this,
			attributes = {
				'class': 'twitter-share-button',
				'href': 'https://twitter.com/share',
				'text': 'Tweet',
				'data-url': self.options.url,
				'data-lang': self.options.lang,
				'data-size': self.options.size
			};

		if ( self.options.text ) {
			attributes['data-text'] = self.options.text;
		}
		if ( self.options.via ) {
			attributes['data-via'] = self.options.via;
		}

		var control = $( '<a></a>', attributes ),
			overlay = $( '<div class="mts-cl-control-overlay"></div>' );

		self.container.find( '.mts-cl-social-control-wrapper' ).after( overlay );
		self.el.replaceWith( control );

		twttr.widgets.load( self.container[0] );

		overlay.on( 'click', function() {
			var def = self.tweet( self.options.auth );
			def.done(function() {
				$( document ).trigger( 'mts-cl-twitter-tweet' );
			});
		});

		return this;
	},

	tweet: function( auth ) {
		var self = this,
			tweetDef = $.Deferred();

		if ( auth ) {

			self.connect(function() {

				var connectDef = self.tweet( false );

				connectDef.done( function() {
					var def = self.check_tweet();

					def.done(function() {
						tweetDef.resolve();
					});
					def.fail(function() {
						self.set_error( cl.__.notices.tweet_not_found );
					});
				});
			});

			return tweetDef;
		}

		cl.__tweetedUrl = self.options.url;

		var url    = 'https://twitter.com/intent/tweet?tw_p=tweetbutton',
			width = 550, height = 420,
			left   = screen.width ? ( ( screen.width / 2 ) - ( width / 2 ) ) + ( window.screenLeft ? window.screenLeft : window.screenX ? window.screenX : 0 )  : 0,
            top    = screen.height ? ( ( screen.height / 2 ) - ( height / 2 ) ) + ( window.screenTop ? window.screenTop : window.screenY ? window.screenY : 0 ) : 0;

		if ( self.options.text ) {
            var text = encodeURI( self.options.text );
            text = text.replace( /#/g, '%23' );
			text = text.replace( /\|/g, '-' );
			text = text.replace( /\&/g, '%26' );
			url += '&text=' + text;
        }

		if ( self.options.via ) {
			url += '&via=' + encodeURIComponent( self.options.via );
		}

		url += '&url=' + encodeURIComponent( self.options.url );

		if ( cl.__twitterAuth && false === cl.__twitterAuth.closed ) {
			cl.__twitterAuth.updateState( url, width, height, left, top );
			cl.__tweetWindow = cl.__twitterAuth;
			cl.__twitterAuth = null;
		} else {
			cl.__tweetWindow = window.open( url, 'Twitter TweetWindow', 'width=' + width + ',height=' + height + ',left=' + left + ',top=' + top );
		}

		setTimeout(function() {
			var interval = setInterval( function() {
				if ( cl.__tweetWindow && cl.__tweetWindow.closed ) {
					clearInterval( interval );
					tweetDef.resolve();
				}
			}, 200 );
		}, 200 );

		return tweetDef.promise();
	},

	connect: function( callback ) {

		var self = this;

		if ( cl.twitterOAuthReady ) {
			self._identify( function( data ) {
				callback( data, { visitor_id: self._visitor_id } );
			});
		} else {
			var options = {
					handler: 'twitter',
					request: 'init',
					options: JSON.stringify( self.options ),
					action: 'mts_cl_connect',
					cl_keep_open: true,
					cl_read_only: true,
					security: __contentlocker.security
				},
				twid = cl.helpers.store.cookie( 'mts_cl_twid' );

			if ( twid && 'null' !== twid ) {
				options.visitor_id = twid;
			}

			var url = __contentlocker.ajaxurl + '?' + $.param( options );

			self._track_window( 'handler=twitter', function() {
				setTimeout(function() {

					if ( cl.twitterOAuthReady ) {
						return;
					}

					self.locker.do_action( 'raw-social-app-declined' );
					self.show_notice( cl.__.errors.not_signed_in );

				}, 500 );
			});

			cl.__twitterAuth = window.open( url, 'Twitter Tweet', 'width=500,height=450,resizable=yes,scrollbars=yes,status=yes' );

			window.mts_cl_twitter_oauth_completed = function( res ) {
				cl.twitterOAuthReady = true;
				self._set_visitor_id( res );
				self.connect( callback );
			};

			window.mts_cl_twitter_oauth_denied = function( res ) {
				self.locker.do_action( 'raw-social-app-declined' );
				self.show_notice( cl.__.errors.not_signed_in );
				self._set_visitor_id( res );
			};
		}
	},

	_set_visitor_id: function( id ) {
		this._visitor_id = id;
		cl.helpers.store.cookie( 'mts_cl_twid', id, {
			expires: '2s'
		});
	},

	_identify: function( callback ) {

		var self = this;

		var request = $.ajax({
			url: __contentlocker.ajaxurl,
			type: 'POST',
			dataType: 'json',
			data: {
				handler: 'twitter',
				request: 'user_info',
				visitor_id: self._visitor_id,
				action: 'mts_cl_connect',
				security: __contentlocker.security
			},

			success: function( response ) {

				if ( ! response || response.error || response.errors ) {
					console.log( 'Unable to get the user data:' + request.responseText );
					return;
				}

				var data = {};
				data.display_name = response.screen_name;
				data.twitter_url = 'https://twitter.com/' + response.screen_name;
				data.image = (function() {
					if ( response.profile_image_url  ) {
						return response.profile_image_url.replace( '_normal', '' );
					}

					return '';
				})();

				callback( data );
			},

			error: function( response ) {

				console.log( 'Unable to get the user data: ' + response.responseText );
				callback({});
			}
		});
	},

	check_tweet: function() {
		var self = this,
			def = $.Deferred();

		var request = $.ajax({
			url: __contentlocker.ajaxurl,
			type: 'POST',
			dataType: 'json',
			data: {
				handler: 'twitter',
				request: 'get_tweets',
				visitor_id: self._visitor_id,
				action: 'mts_cl_connect',
				cl_read_only: true,
				security: __contentlocker.security
			},

			success: function( response ) {

				if ( ! response || response.error || response.errors ) {
					console.log( 'Unable to tweet:' + request.responseText );
				}

				for ( var e = 0; e < response.length; e++ ) {
					if ( response[e].entities ) {
						for ( var f = 0; f < response[e].entities.urls.length; f++ ) {
							if ( response[e].entities.urls[f] && response[e].entities.urls[f].expanded_url === self.options.url ) {
								def.resolve();
								return;
							}
						}
					}
				}
                def.reject();
			},

			error: function() {
				console.log( 'Unable to tweet: ' + request.responseText );
				def.reject();
			}
		});

		return def.promise();
	},

	// Private
	_track_window: function( search, callback ) {

		var original = window.open;

		window.open = function( url, name, specs, replace ) {
			var popup = original( url, name, specs, replace );

			if ( ! popup ) {
				return popup;
			}

			if ( ! url.includes( search ) ) {
				return popup;
			}

			var interval = setInterval( function() {

				if ( popup && popup.closed ) {
					clearInterval( interval );

					if ( callback ) {
						callback();
					}
				}
			}, 300 );

			return popup;
		};
	}
});
cl.controls['twitter-tweet'] = TwitterTweet;
