/*!
 * Locker StateStorage
 *
 * @since 1.0.0
 * @pacakge core
*/
/*jshint -W003*/
var StateStorage = function( locker ) {
	this.locker = locker;

	// Relock strategy here
	this.always = locker.options.always;
	this.expires = locker.options.expires;
};

_.extend( StateStorage.prototype, {

	is_unlocked: function( id ) {

		if ( this.always ) {
			return false;
		}

		return this.get( id ) ? true : false;
	},

	is_locked: function( id ) {
		return ! this.is_unlocked( id );
	},

	can_lock: function( id ) {
		return ! this.is_unlocked( id );
	},

	request_state: function( id ) {

		return this.is_unlocked( id ) ? 'unlocked' : 'locked';
	},

	set_state: function( id, state ) {

		if ( this.always ) {
			return true;
		}

		return 'unlocked' === state ? this.set( id ) : this.remove( id );
	},

	set: function( id ) {

		if ( ! id ) {
			return false;
		}

		return cl.helpers.store.set( id, true, { expires: this.expires } );
	},

	get: function( id ) {

		if ( ! id ) {
			return false;
		}

		return cl.helpers.store.get( id );
	},

	remove: function( id ) {

		if ( ! id ) {
			return false;
		}

		return cl.helpers.store.remove( id );
	}
});
cl.StateStorage = StateStorage;
