/*!
 * Control Sdks
 *
 * @since 1.0.0
 * @pacakge core
*/

// Base SDK
cl.sdk = {

	_connected: [],

	is_connected: function( sdk ) {

		if ( $( '#' + sdk.id ).length > 0 ) {
			return true;
		}

		var result = false;

		$( 'script' ).each(function() {
			var $this = $( this ),
				src = $this.attr( 'src' );

			if ( src && -1 !== src.indexOf( sdk.url ) ) {
				$this.attr( 'id', sdk.id );
				return true;
			}
		});

		return result;
	},

	is_loaded: function( sdk ) {
		return this.is_connected( sdk ) && sdk.is_loaded && sdk.is_loaded();
	},

	connect: function( name ) {
		var sdk = _.has( cl.sdk, name ) ? cl.sdk[name] : null,
			def = $.Deferred();

		// If no sdk
		if ( ! sdk ) {
			console.log( 'Invalide SDK: ' + name );
			def.reject( 'invalid-sdk' );
			return def.promise();
		}

		// If already setup
		if ( sdk.loaded && sdk.is_loaded() ) {
			def.resolve();
			return def.promise();
		}

		$( document ).bind( name + '-init', function() {
			def.resolve();
		});

		$( document ).bind( name + '-error', function() {
			def.reject( 'error-load' );
		});

		if ( ! this._connected[name] ) {

			sdk.init && sdk.init();
			this.loader( sdk );

			this._connected[sdk.name] = true;
		}

		return def.promise();
	},

	loader: function( sdk ) {

		if ( document.getElementById( sdk.id ) && sdk.setup ) {
			return;
		}

		if ( document.getElementById( sdk.id ) && ! sdk.setup ) {
			sdk.id += '-1';
		}

		var js = document.createElement( 'script' );
		js.id = sdk.id;
		js.src = sdk.url;
		js.async = true;

		// Create events
		sdk.events && sdk.events();

		// If no url i.e. email subscription
		if ( ! sdk.url ) {
			sdk.loaded = true;
			return;
		}

		// Load Detection
		js.onload = js.onreadystatechange = function() {

			if ( /^($|loaded|complete)/.test( js.readyState || '' ) ) {
				js.onload = js.onreadystatechange = null;
				sdk.loaded = true;
				$( document ).trigger( sdk.name + '-script-loaded' );
			}
		};

		// Error Detection
		js.onerror = function() {
			js.onerror = null;
			sdk.loaded = false;
			$( document ).trigger( sdk.name + '-error' );
		};

		var fjs = document.getElementsByTagName( 'script' )[0];
		fjs.parentNode.insertBefore( js, fjs );
	}
};
